@@ -1,7 +1,7 @@
 /* imagecodecs/imcd.c */
 
 /*
-Copyright (c) 2008-2024, Christoph Gohlke.
+Copyright (c) 2008-2026, Christoph Gohlke.
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -513,7 +513,7 @@ ssize_t imcd_byteshuffle(
         /* TODO: do not temporarily modify src */
         if (delta) {
             /* undo byte differencing; separate for interleaved samples */
-            for (i = samples; i < size*itemsize; i++) {
+            for (i = samples; i < size * itemsize; i++) {
                 srcptr[i] += srcptr[i - samples];
             }
         }
@@ -693,10 +693,8 @@ inline uint8_t* _packbits_next_replicate(
 {
     uint8_t value = (srcptr < srcend) ? *srcptr : 0;
 
-    while (++srcptr < srcend)
-    {
-        if (value == *srcptr)
-        {
+    while (++srcptr < srcend) {
+        if (value == *srcptr) {
             return srcptr - 1;
         }
         value = *srcptr;
@@ -744,8 +742,7 @@ ssize_t imcd_packbits_encode(
     while (srcptr < srcend)
     {
         dupptr = _packbits_next_replicate(srcptr, srcend);
-        if (srcptr == dupptr)
-        {
+        if (srcptr == dupptr) {
             /* replicate */
             replicate = _packbits_replicate_length(dupptr, srcend);
             replicate = MIN_(128, replicate);
@@ -770,10 +767,8 @@ ssize_t imcd_packbits_encode(
             if (replicate < 3) {
                 uint8_t* nextsrc = dupptr + replicate;
                 uint8_t* nextdup = _packbits_next_replicate(nextsrc, srcend);
-                if (nextdup > nextsrc) {
-                    /* discard 2-byte run */
-                    dupptr = nextdup;
-                }
+                /* discard 2-byte run? */
+                dupptr = (nextdup > nextsrc) ? nextdup : dupptr;
             }
             literal = dupptr - srcptr;
         }
@@ -783,6 +778,9 @@ ssize_t imcd_packbits_encode(
             while (literal--) {
                 *dstptr++ = *srcptr++;
             }
+            /* memcpy(dstptr, srcptr, literal); */
+            /* dstptr += literal; */
+            /* srcptr += literal; */
         }
         else {
             dstptr = NULL;
@@ -791,8 +789,7 @@ ssize_t imcd_packbits_encode(
     }
 
     if (dstptr == NULL) {
-        if (dstsize < maxdst)
-        {
+        if (dstsize < maxdst) {
             return IMCD_OUTPUT_TOO_SMALL;
         }
         /* encoding exceeded maximum literal-only length */
@@ -800,13 +797,15 @@ ssize_t imcd_packbits_encode(
         literal = srcsize;
         srcptr = (uint8_t*)src;
         dstptr = dst;
-        while (srcptr < srcend)
-        {
+        while (srcptr < srcend) {
             literal = MIN_(128, srcend - srcptr);
             *dstptr++ = (uint8_t)(literal - 1);
             while (literal--) {
                 *dstptr++ = *srcptr++;
             }
+            /* memcpy(dstptr, srcptr, literal); */
+            /* dstptr += literal; */
+            /* srcptr += literal; */
         }
     }
     return (ssize_t)(dstptr - dst);
@@ -872,7 +871,7 @@ ssize_t imcd_ccittrle_decode(
     uint8_t* srcptr = (uint8_t*)src;
     uint8_t* dstptr = dst;
     const uint8_t* srcend = srcptr + srcsize;
-    const uint8_t* dstend = dstptr + dstsize;
+    /* const uint8_t* dstend = dstptr + dstsize; */
 
     if ((srcptr == NULL) || (srcsize < 0) || (dstptr == NULL) || (dstsize < 0))
     {
@@ -1120,7 +1119,7 @@ ssize_t imcd_packints_encode(
     const int bps  /** number of bits in integer */
     )
 {
-    ssize_t i, j, k;
+    ssize_t i, j;
     ssize_t itemsize;
     uint8_t value;
 
@@ -1244,7 +1243,7 @@ ssize_t imcd_float24_decode(
     const uint8_t* src,
     const ssize_t srcsize,
     uint8_t* dst,
-    const char byteorder)
+    const int islittle)
 {
     /* input validation is done in wrapper function */
 
@@ -1259,7 +1258,7 @@ ssize_t imcd_float24_decode(
     }
 
     for (i = 0; i < srcsize; i += 3) {
-        if (byteorder == '<') {
+        if (islittle) {
             /* from little endian */
             s2 = *src++;
             s1 = *src++;
@@ -1341,7 +1340,7 @@ ssize_t imcd_float24_encode(
     const uint8_t* src,
     const ssize_t srcsize,
     uint8_t* dst,
-    const char byteorder,
+    const int islittle,
     int rounding)
 {
     /* input validation is done in wrapper function */
@@ -1492,12 +1491,13 @@ ssize_t imcd_float24_encode(
                 }
             }
         }
-        if (byteorder == '<') {
+        if (islittle) {
             /* to little endian */
             *dst++ = f2;
             *dst++ = f1;
             *dst++ = f0;
-        } else {
+        }
+        else {
             /* to big endian */
             *dst++ = f0;
             *dst++ = f1;
@@ -1508,6 +1508,117 @@ ssize_t imcd_float24_encode(
 }
 
 
+/********************************* Bfloat16 **********************************/
+
+/* https://en.wikipedia.org/wiki/Bfloat16_floating-point_format */
+
+ssize_t imcd_bfloat16_decode(
+    const uint8_t* src,
+    const ssize_t srcsize,
+    uint8_t* dst,
+    const int islittle)
+{
+    /* input validation is done in wrapper function */
+
+    ssize_t i;
+    uint8_t f0, f1;
+
+    if (srcsize < 2) {
+        return 0;
+    }
+
+    for (i = 0; i < srcsize; i += 2) {
+        if (islittle) {
+            /* from little endian */
+            f1 = *src++;
+            f0 = *src++;
+        }
+        else {
+            /* from big endian */
+            f0 = *src++;
+            f1 = *src++;
+        }
+
+#if IMCD_MSB
+        /* to little endian */
+        *dst++ = 0;
+        *dst++ = 0;
+        *dst++ = f1;
+        *dst++ = f0;
+#else
+        /* to big endian */
+        *dst++ = f0;
+        *dst++ = f1;
+        *dst++ = 0;
+        *dst++ = 0;
+#endif
+    }
+    return (srcsize / 2) * 2;
+}
+
+
+ssize_t imcd_bfloat16_encode(
+    const uint8_t* src,
+    const ssize_t srcsize,
+    uint8_t* dst,
+    const int islittle,
+    int rounding)
+{
+    /* input validation is done in wrapper function */
+
+    ssize_t i;
+    uint8_t f0, f1;
+    uint32_t uvalue;
+    float fvalue;
+
+    if (srcsize < 4) {
+        return 0;
+    }
+
+    /* always round a half value to nearest even */
+    /*
+    if (rounding < 0) {
+        rounding = fegetround();
+    }
+    if (
+        (rounding != FE_TONEAREST) &&
+        (rounding != FE_TOWARDZERO) &&
+        (rounding != FE_UPWARD) &&
+        (rounding != FE_DOWNWARD)
+    ) {
+        rounding = FE_TONEAREST;
+    }
+    */
+
+    for (i = 0; i < srcsize; i += 4) {
+        memcpy(&fvalue, &src[i], 4);
+
+        if (isnan(fvalue)) {
+            f0 = signbit(fvalue) ? 0xFF : 0x7F;
+            f1 = 0xC0;
+        }
+        else {
+            /* memcpy(&uvalue, &src[i], 4); */
+            uvalue = *((uint32_t*) &fvalue);
+            uvalue += 0x7fff + ((uvalue >> 16) & 1);
+            f1 = (uvalue >> 16) & 0xFF;
+            f0 = (uvalue >> 24) & 0xFF;
+        }
+        if (islittle) {
+            /* to little endian */
+            *dst++ = f1;
+            *dst++ = f0;
+        }
+        else {
+            /* to big endian */
+            *dst++ = f0;
+            *dst++ = f1;
+        }
+    }
+    return (srcsize / 4) * 4;
+}
+
+
 /*********************** Electron Event Representation ***********************/
 
 /* EER file format documentation 3.0. Section 4. by M. Leichsenring. March 2023
@@ -1519,99 +1630,178 @@ detected electron events with sub pixel information.
 
 ssize_t
 imcd_eer_decode(
-    const uint8_t *src,
+    const uint8_t* src,
     const ssize_t srcsize,
-    uint8_t *dst,
+    uint8_t* dst,
     const ssize_t height,
     const ssize_t width,
-    const int rlebits,
-    const int horzbits,
-    const int vertbits,
-    const bool superres)
+    const uint32_t skipbits,
+    const uint32_t horzbits,
+    const uint32_t vertbits,
+    const uint32_t superres)
 {
     const ssize_t dstsize = height * width;
-    const ssize_t nbits = rlebits + horzbits + vertbits;
+    const ssize_t nbits = skipbits + horzbits + vertbits;
     const ssize_t srcbits = srcsize * 8 - nbits;
-    const uint16_t rlemask = imcd_bitmask2(rlebits);
-    const uint16_t horzmask = imcd_bitmask2(horzbits);
-    const uint16_t vertmask = imcd_bitmask2(vertbits);
-    const ssize_t horzsize = (ssize_t)horzmask + 1;
-    const ssize_t vertsize = (ssize_t)vertmask + 1;
+    const uint32_t skipmask = imcd_bitmask2(skipbits);
+    const uint32_t horzmask = imcd_bitmask2(horzbits);
+    const uint32_t vertmask = imcd_bitmask2(vertbits);
+    const uint32_t horzshift = MAX_(0, (ssize_t)horzbits - (ssize_t)superres);
+    const uint32_t vertshift = MAX_(0, (ssize_t)vertbits - (ssize_t)superres);
+    const ssize_t horzsize = (ssize_t)((horzmask + 1) >> horzshift);
+    const ssize_t vertsize = (ssize_t)((vertmask + 1) >> vertshift);
     const ssize_t width2 = width / horzsize;
+    const ssize_t pixelsize = dstsize / (horzsize * vertsize);
     ssize_t bitindex = 0;
-    ssize_t pixelindex = 0;
     ssize_t dstindex = 0;
+    ssize_t pixelindex = 0;
     ssize_t events = 0;
-    uint16_t word = 0;
-    uint16_t rle = 0;
+    uint32_t word = 0;
+    uint32_t skip = 0;
     ssize_t v, h;
 
-    if ((src == NULL) || (srcsize < 2) || (dst == NULL) || (height < 1) ||
-        (width < 1) || (nbits > 16) || (nbits <= 8) || (rlebits < 4) ||
-        (horzbits < 1) || (vertbits < 1)) {
+    if ((src == NULL) || (srcsize % 2) || (dst == NULL) ||
+        (height < 1) || (width < 1) || (nbits > 16) || (nbits <= 8) ||
+        (skipbits < 4) || (horzbits < 1) || (vertbits < 1)) {
         return IMCD_VALUE_ERROR;
     }
 
-    if (superres) {
-        if ((width % horzsize) || (height % vertsize)) {
-            return IMCD_VALUE_ERROR;
-        }
-        while (bitindex < srcbits) {
-            word = *((uint16_t *)(src + (bitindex / 8)));
-            word >>= bitindex % 8;
-            rle = word & rlemask;
-            pixelindex += (ssize_t)rle;
-            if (rle == rlemask) {
-                bitindex += rlebits;
-                continue;
-            }
-            word >>= rlebits;
-            v = (ssize_t)((word & vertmask) ^ ((uint16_t)1 << (vertbits - 1)));
-            word >>= vertbits;
-            h = (ssize_t)((word & horzmask) ^ ((uint16_t)1 << (horzbits - 1)));
-            v += (pixelindex / width2) * vertsize;
-            h += (pixelindex % width2) * horzsize;
-            dstindex = v * width + h;
-            if (dstindex == dstsize) {
-                break;
-            }
-            if (dstindex < 0) {
-                return IMCD_INPUT_CORRUPT;
-            }
-            if (dstindex > dstsize) {
-                return IMCD_OUTPUT_TOO_SMALL;
-            }
-            dst[dstindex] += 1;
-            pixelindex++;
-            events++;
-            bitindex += nbits;
-        }
-    } else {
-        while (bitindex < srcbits) {
-            word = *((uint16_t *)(src + (bitindex / 8)));
-            word >>= bitindex % 8;
-            rle = word & rlemask;
-            dstindex += rle;
-            if (dstindex == dstsize) {
-                break;
-            }
-            if (dstindex < 0) {
-                return IMCD_INPUT_CORRUPT;
-            }
-            if (dstindex > dstsize) {
-                return IMCD_OUTPUT_TOO_SMALL;
-            }
-            if (rle == rlemask) {
-                bitindex += rlebits;
-                continue;
-            }
-            dst[dstindex] += 1;
-            dstindex++;
-            events++;
-            bitindex += nbits;
-        }
+    if ((superres > 0) && ((width % horzsize) || (height % vertsize))) {
+        return IMCD_VALUE_ERROR;
     }
 
+    while (bitindex < srcbits) {
+        word = 0;
+        v = bitindex / 8;
+        h = srcsize - v;
+        memcpy(&word, src + v, h > 3 ? 4 : h);
+        word >>= bitindex % 8;
+        skip = word & skipmask;
+        pixelindex += (ssize_t)skip;
+        if (pixelindex == pixelsize) {
+            break;
+        }
+        if (pixelindex < 0) {
+            return IMCD_INPUT_CORRUPT;
+        }
+        if (pixelindex > pixelsize) {
+            return IMCD_OUTPUT_TOO_SMALL;
+        }
+        if (skip == skipmask) {
+            bitindex += skipbits;
+            continue;
+        }
+        if (superres == 0) {
+            dstindex = pixelindex;
+        }
+        else {
+            word >>= skipbits;
+            h = (ssize_t)(((word & horzmask) ^ horzbits) >> horzshift);
+            h += (pixelindex % width2) * horzsize;
+
+            word >>= horzbits;
+            v = (ssize_t)(((word & vertmask) ^ vertbits) >> vertshift);
+            v += (pixelindex / width2) * vertsize;
+
+            dstindex = v * width + h;
+            if (dstindex >= dstsize) {
+                return IMCD_OUTPUT_TOO_SMALL;
+            }
+        }
+        dst[dstindex] += 1;
+        pixelindex++;
+        bitindex += nbits;
+        events++;
+    }
+    return events;
+}
+
+
+ssize_t
+imcd_eer_decode_u2(
+    const uint8_t* src,
+    const ssize_t srcsize,
+    uint16_t* dst,
+    const ssize_t height,
+    const ssize_t width,
+    const uint32_t skipbits,
+    const uint32_t horzbits,
+    const uint32_t vertbits,
+    const uint32_t superres)
+{
+    const ssize_t dstsize = height * width;
+    const ssize_t nbits = skipbits + horzbits + vertbits;
+    const ssize_t srcbits = srcsize * 8 - nbits;
+    const uint32_t skipmask = imcd_bitmask2(skipbits);
+    const uint32_t horzmask = imcd_bitmask2(horzbits);
+    const uint32_t vertmask = imcd_bitmask2(vertbits);
+    const uint32_t horzshift = MAX_(0, (ssize_t)horzbits - (ssize_t)superres);
+    const uint32_t vertshift = MAX_(0, (ssize_t)vertbits - (ssize_t)superres);
+    const ssize_t horzsize = (ssize_t)((horzmask + 1) >> horzshift);
+    const ssize_t vertsize = (ssize_t)((vertmask + 1) >> vertshift);
+    const ssize_t width2 = width / horzsize;
+    const ssize_t pixelsize = dstsize / (horzsize * vertsize);
+    ssize_t bitindex = 0;
+    ssize_t dstindex = 0;
+    ssize_t pixelindex = 0;
+    ssize_t events = 0;
+    uint32_t word = 0;
+    uint32_t skip = 0;
+    ssize_t v, h;
+
+    if ((src == NULL) || (srcsize % 2) || (dst == NULL) ||
+        (height < 1) || (width < 1) || (nbits > 16) || (nbits <= 8) ||
+        (skipbits < 4) || (horzbits < 1) || (vertbits < 1)) {
+        return IMCD_VALUE_ERROR;
+    }
+
+    if ((superres > 0) && ((width % horzsize) || (height % vertsize))) {
+        return IMCD_VALUE_ERROR;
+    }
+
+    while (bitindex < srcbits) {
+        word = 0;
+        v = bitindex / 8;
+        h = srcsize - v;
+        memcpy(&word, src + v, h > 3 ? 4 : h);
+        word >>= bitindex % 8;
+        skip = word & skipmask;
+        pixelindex += (ssize_t)skip;
+        if (pixelindex == pixelsize) {
+            break;
+        }
+        if (pixelindex < 0) {
+            return IMCD_INPUT_CORRUPT;
+        }
+        if (pixelindex > pixelsize) {
+            return IMCD_OUTPUT_TOO_SMALL;
+        }
+        if (skip == skipmask) {
+            bitindex += skipbits;
+            continue;
+        }
+        if (superres == 0) {
+            dstindex = pixelindex;
+        }
+        else {
+            word >>= skipbits;
+            h = (ssize_t)(((word & horzmask) ^ horzbits) >> horzshift);
+            h += (pixelindex % width2) * horzsize;
+
+            word >>= horzbits;
+            v = (ssize_t)(((word & vertmask) ^ vertbits) >> vertshift);
+            v += (pixelindex / width2) * vertsize;
+
+            dstindex = v * width + h;
+            if (dstindex >= dstsize) {
+                return IMCD_OUTPUT_TOO_SMALL;
+            }
+        }
+        dst[dstindex] += 1;
+        pixelindex++;
+        bitindex += nbits;
+        events++;
+    }
     return events;
 }
 
@@ -1655,14 +1845,15 @@ ssize_t _lzw_alloc_buffer(
     }
     else {
         /* reallocate buffer */
-        void *tmp = NULL;
+        void* tmp = NULL;
         buffersize = (((buffersize-1) / LZW_BUFFERSIZE) + 1) * LZW_BUFFERSIZE;
-        tmp = realloc((void *)handle->buffer, buffersize);
+        tmp = realloc((void*)handle->buffer, buffersize);
         if (tmp == NULL) {
             free(handle->buffer);
             handle->buffer = NULL;
-        } else {
-            handle->buffer = (uint8_t *)tmp;
+        }
+        else {
+            handle->buffer = (uint8_t*)tmp;
         }
     }
 
@@ -1714,17 +1905,24 @@ void imcd_lzw_del(imcd_lzw_handle_t* handle)
 {  \
     if ((bitcount + bitw) <= srcbitsize)  \
     {  \
-        const uint8_t* bytes = (uint8_t*)((void*)(src + (bitcount >> 3)));  \
-        code = (uint32_t) bytes[0];  \
-        code <<= 8;  \
-        code |= (uint32_t) bytes[1];  \
-        code <<= 8;  \
-        if ((bitcount + 24) <= srcbitsize)  \
-            code |= (uint32_t) bytes[2];  \
-        code <<= 8;  \
-        code <<= (uint32_t)(bitcount % 8);  \
-        code &= mask;  \
-        code >>= shr;  \
+        const uint32_t bitoffset = bitcount & 0x7;  \
+        const uint8_t* bytes = src + (bitcount >> 3);  \
+        if (bitoffset == 0 && bitw <= 24) {  \
+            code = (bytes[0] << 16) | (bytes[1] << 8) | bytes[2];  \
+            code >>= (24 - bitw);  \
+        } \
+        else {  \
+            code = (uint32_t) bytes[0];  \
+            code <<= 8;  \
+            code |= (uint32_t) bytes[1];  \
+            code <<= 8;  \
+            if ((bitcount + 24) <= srcbitsize)  \
+                code |= (uint32_t) bytes[2];  \
+            code <<= 8;  \
+            code <<= bitoffset;  \
+            code &= mask;  \
+            code >>= shr;  \
+        }  \
         bitcount += bitw;  \
     }  \
     else {code = LZW_EOI;}  \
@@ -1931,7 +2129,7 @@ ssize_t imcd_lzw_decode(
     uint8_t* dst,
     const ssize_t dstsize)
 {
-    const uint8_t *dstin = dst;
+    const uint8_t* dstin = dst;
     imcd_lzw_table_t* table;
     uint8_t* buffer;
     uint32_t tablesize = 258;
@@ -2032,11 +2230,8 @@ ssize_t imcd_lzw_decode(
                 const uint8_t* oldbuffer = handle->buffer;
                 const ssize_t bufferlen = buffer - oldbuffer;
 
-                if (
-                    _lzw_alloc_buffer(handle, handle->buffersize - buffersize)
-                    <= 0
-                    )
-                {
+                if (_lzw_alloc_buffer(
+                        handle, handle->buffersize - buffersize) <= 0) {
                     return IMCD_MEMORY_ERROR;
                 }
                 if (handle->buffer != oldbuffer) {
@@ -2065,13 +2260,13 @@ ssize_t imcd_lzw_decode(
             else {
                 uint8_t* pstr = table[code].buf;
                 ssize_t len = table[code].len;
-                if (len > remaining) {
-                    len = remaining;
-                }
+                len = (len > remaining) ? remaining : len;
                 remaining -= len;
                 for (i = 0; i < len; i++) {
                     *dst++ = *pstr++;
                 }
+                /* memcpy(dst, table[code].buf, len); */
+                /* dst += len; */
             }
             /* table.append(table[oldcode] + table[code][0]) */
             table[tablesize].buf = buffer;
@@ -2083,13 +2278,11 @@ ssize_t imcd_lzw_decode(
                 for (i = 0; i < table[oldcode].len; i++) {
                     *buffer++ = *pstr++;
                 }
+                /* const ssize_t len = table[oldcode].len; */
+                /* memcpy(buffer, table[oldcode].buf, len); */
+                /* buffer += len; */
             }
-            if (code < 256) {
-                *buffer++ = (uint8_t) code;
-            }
-            else {
-                *buffer++ = table[code].buf[0];
-            }
+            *buffer++ = (code < 256) ? (uint8_t) code : table[code].buf[0];
         }
         else if (code > tablesize) {
             /* return dstsize - remaining; */
@@ -2110,13 +2303,13 @@ ssize_t imcd_lzw_decode(
             else {
                 uint8_t* pstr = table[oldcode].buf;
                 ssize_t len = table[oldcode].len;
-                if (len > remaining) {
-                    len = remaining;
-                }
+                len = (len > remaining) ? remaining : len;
                 remaining -= len;
                 for (i = 0; i < len; i++) {
                     *dst++ = *pstr++;
                 }
+                /* memcpy(dst, table[oldcode].buf, len); */
+                /* dst += len; */
                 if (--remaining < 0) break;
                 *dst++ = table[oldcode].buf[0];
             }
@@ -2179,16 +2372,16 @@ ssize_t imcd_lzw_encode_size(const ssize_t srcsize)
 
 /* Encode LZW. */
 ssize_t imcd_lzw_encode(
-    const uint8_t *src,
+    const uint8_t* src,
     const ssize_t srcsize,
-    uint8_t *dst,
+    uint8_t* dst,
     const ssize_t dstsize
 ) {
     ssize_t i = 0;
     ssize_t dstindex = 0;
     ssize_t srcindex = 0;
-    int *hash_keys = NULL;
-    int *hash_values = NULL;
+    int* hash_keys = NULL;
+    int* hash_values = NULL;
     int hashkey = 0;
     int hashcode = 0;
     int nextcode = LZW_FIRST;
@@ -2244,7 +2437,7 @@ ssize_t imcd_lzw_encode(
 
         while (hash_keys[hashcode] >= 0) {
             if (hash_keys[hashcode] == hashkey) {
-                // Omega+K in table
+                /* Omega+K in table */
                 omega = hash_values[hashcode];
                 goto OUTER;
             }
@@ -2254,7 +2447,7 @@ ssize_t imcd_lzw_encode(
             }
         }
 
-        // Omega+K not in table
+        /* Omega+K not in table */
         /* add entry to table */
         hash_keys[hashcode] = hashkey;
         hash_values[hashcode] = nextcode++;
@@ -2345,9 +2538,9 @@ ssize_t imcd_lzw_encode(
 
 /* search for bytes in bytes */
 ssize_t imcd_memsearch(
-    const char *src,
+    const char* src,
     const ssize_t srclen,
-    const char *dst,
+    const char* dst,
     const ssize_t dstlen) {
     for (ssize_t i = 0; i < srclen; i++) {
         if (src[i] == dst[0]) {
@@ -2370,9 +2563,9 @@ ssize_t imcd_memsearch(
 
 /* search for bytes in string; stop at null character */
 ssize_t imcd_strsearch(
-    const char *src,
+    const char* src,
     const ssize_t srclen,
-    const char *dst,
+    const char* dst,
     const ssize_t dstlen) {
     for (ssize_t i = 0; i < srclen; i++) {
         if (src[i] == '\0') {
